aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAndrew Gerrand <adg@golang.org>2010-03-20 10:22:09 +1100
committerAndrew Gerrand <adg@golang.org>2010-03-20 10:22:09 +1100
commitf4322a848d651a8cc8bf5ec9a762e3dbca7ed784 (patch)
treee3e2a0eb6cf2ee4535c307c3587c1757cd039515
parent791a26734f2f4d9dcfb7a19be9482347bf34bdf6 (diff)
downloadgo-f4322a848d651a8cc8bf5ec9a762e3dbca7ed784.tar.gz
go-f4322a848d651a8cc8bf5ec9a762e3dbca7ed784.zip
http: add Error helper function
R=r, rsc CC=golang-dev https://golang.org/cl/626042
-rw-r--r--src/pkg/http/server.go11
1 files changed, 7 insertions, 4 deletions
diff --git a/src/pkg/http/server.go b/src/pkg/http/server.go
index f0b608ddeb..39b498a7ac 100644
--- a/src/pkg/http/server.go
+++ b/src/pkg/http/server.go
@@ -328,13 +328,16 @@ func (f HandlerFunc) ServeHTTP(c *Conn, req *Request) {
// Helper handlers
-// NotFound replies to the request with an HTTP 404 not found error.
-func NotFound(c *Conn, req *Request) {
+// Error replies to the request with the specified error message and HTTP code.
+func Error(c *Conn, error string, code int) {
c.SetHeader("Content-Type", "text/plain; charset=utf-8")
- c.WriteHeader(StatusNotFound)
- io.WriteString(c, "404 page not found\n")
+ c.WriteHeader(code)
+ fmt.Fprintln(c, error)
}
+// NotFound replies to the request with an HTTP 404 not found error.
+func NotFound(c *Conn, req *Request) { Error(c, "404 page not found", StatusNotFound) }
+
// NotFoundHandler returns a simple request handler
// that replies to each request with a ``404 page not found'' reply.
func NotFoundHandler() Handler { return HandlerFunc(NotFound) }